@@ -13,7 +13,7 @@ use Pinto::Types qw(AuthorID FileList);
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_05'; # VERSION
+our $VERSION = '0.065_06'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -80,11 +80,12 @@ sub execute {
         }
         catch {
             throw $_ unless $self->no_fail; 
+            $self->result->failed(because => $_);
 
             $self->repo->svp_rollback;
 
             $self->error("$_");
-            $self->error("$archive failed...continuing anyway");
+            $self->error("Archive $archive failed...continuing anyway");
             push @failed, $archive;
         }
         finally {
@@ -152,7 +153,7 @@ Pinto::Action::Add - Add a local distribution into the repository
 
 =head1 VERSION
 
-version 0.065_05
+version 0.065_06
 
 =head1 AUTHOR
 
