@@ -5,7 +5,7 @@ package Pinto::ArchiveUnpacker;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw(Bool);
-use MooseX::MarkAsMethods ( autoclean => 1 );
+use MooseX::MarkAsMethods (autoclean => 1);
 
 use Cwd qw(getcwd);
 use Cwd::Guard qw(cwd_guard);
@@ -18,7 +18,7 @@ use Pinto::Util qw(debug throw);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.11_01'; # VERSION
+our $VERSION = '0.065_06'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -29,17 +29,19 @@ has archive => (
     coerce   => 1,
 );
 
+
 has temp_dir => (
-    is      => 'ro',
-    isa     => 'File::Temp::Dir',
-    default => sub { File::Temp->newdir( CLEANUP => $_[0]->cleanup ) },
-    lazy    => 1,
+    is       => 'ro',
+    isa      => 'File::Temp::Dir',
+    default  => sub { File::Temp->newdir(CLEANUP => $_[0]->cleanup) },
+    lazy     => 1,
 );
 
+
 has cleanup => (
-    is      => 'ro',
-    isa     => Bool,
-    default => 1,
+    is       => 'ro',
+    isa      => Bool,
+    default  => 1,
 );
 
 #-----------------------------------------------------------------------------
@@ -49,20 +51,20 @@ sub unpack {
 
     my $archive   = $self->archive;
     my $temp_dir  = $self->temp_dir->dirname;
-    my $cwd_guard = cwd_guard(getcwd);          # Archive::Extract will chdir
+    my $cwd_guard = cwd_guard(getcwd); # Archive::Extract will chdir
 
     local $Archive::Extract::PREFER_BIN = 1;
-    local $Archive::Extract::DEBUG = 1 if ( $ENV{PINTO_DEBUG} || 0 ) > 1;
+    local $Archive::Extract::DEBUG = 1 if ($ENV{PINTO_DEBUG} || 0) > 1;
 
-    my $ae = Archive::Extract->new( archive => $archive );
+    my $ae = Archive::Extract->new(archive => $archive);
 
     debug "Unpacking $archive into $temp_dir";
 
-    my $ok = $ae->extract( to => $temp_dir );
+    my $ok = $ae->extract(to => $temp_dir);
     throw "Failed to unpack $archive: " . $ae->error if not $ok;
 
     my @children = dir($temp_dir)->children;
-    return @children == 1 && -d $children[0] ? $children[0] : dir($temp_dir);
+    return @children == 1 ? $children[0] : dir($temp_dir);
 }
 
 #-----------------------------------------------------------------------------
@@ -77,9 +79,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
-=for :stopwords Jeffrey Ryan Thalhammer
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -87,7 +87,7 @@ Pinto::ArchiveUnpacker - Unpack an archive into a temporary directory
 
 =head1 VERSION
 
-version 0.11_01
+version 0.065_06
 
 =head1 AUTHOR
 
@@ -95,7 +95,7 @@ Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2011 by Imaginative Software Systems.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
