@@ -11,7 +11,7 @@ use Pinto::Util qw(is_interactive);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.065_05'; # VERSION
+our $VERSION = '0.065_06'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -30,19 +30,23 @@ has quiet   => (
 
 #-----------------------------------------------------------------------------
 
-sub show { return shift }
+sub show { return 1 }
 
 #-----------------------------------------------------------------------------
 
-sub diag { return shift }
+sub diag { return 1 }
 
 #-----------------------------------------------------------------------------
 
-sub show_progress { return shift }
+sub edit { return shift }
 
 #-----------------------------------------------------------------------------
 
-sub progress_done { return shift }
+sub show_progress { return 1 }
+
+#-----------------------------------------------------------------------------
+
+sub progress_done { return 1 }
 
 #-----------------------------------------------------------------------------
 
@@ -111,7 +115,7 @@ Pinto::Chrome - Base class for interactive interfaces
 
 =head1 VERSION
 
-version 0.065_05
+version 0.065_06
 
 =head1 AUTHOR
 
